MW_CREATININE = 113.12  # g/mol

# in g/mol
molecular_weights = dict(
    albumin=66000,
    chol=386.65,
    creatinine=113.12,
    glucose=180.16,
    haemoglobin=64500,
    tbil=584.6,
    trig=885,
    urea=60.06,
)
